Deletes all locally cached files. The next call to any data function will re-download from the Clean Energy Regulator.
See also
Other configuration:
cer_cache_info()
Deletes all locally cached files. The next call to any data function will re-download from the Clean Energy Regulator.
Other configuration:
cer_cache_info()